@@ -233,7 +233,6 @@ xnee_human_print_request (xnee_data *xd, XRecordInterceptData *xrecintd )
   xrec_data  = (XRecordDatum *) (xrecintd->data) ;
 
   request_type = (int)xrec_data->type ;
-  request_name = " not defined " ;
 
   request_name = xnee_print_request(request_type);
     if ( request_name == NULL )
@@ -333,7 +332,6 @@ xnee_human_print_event (xnee_data *xd, XRecordInterceptData *xrecintd )
   char  *name=" not defined " ;
   xrec_data  = (XRecordDatum *) (xrecintd->data) ;
   event_type = (int)xrec_data->type ;
-  event_name = " not defined " ;
 
   event_name = xnee_print_event(event_type);
     if ( event_name == NULL )
@@ -344,6 +342,10 @@ xnee_human_print_event (xnee_data *xd, XRecordInterceptData *xrecintd )
   (void)xd->data_fp (xd->out_file,"Event" XNEE_HP_EQUALS "%s" XNEE_HP_SEP "Number" XNEE_HP_EQUALS "%d", 
 		     event_name, event_type);
   
+  xnee_handle_xinput_event_human(xd, 
+				 event_type, 
+				 xrec_data);
+
   if ( 1 )
     {
       (void)xd->data_fp (xd->out_file,XNEE_HP_CONTENT_BEGIN); 
