@@ -3,7 +3,8 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 
+ *                 2006, 2007, 2010
  *                        Henrik Sandklef 
  *                                                                   
  * This program is free software; you can redistribute it and/or     
@@ -99,10 +100,6 @@ xnee_start(xnee_data *xd)
       handled by normal parsing ..... */
    if (xnee_is_syntax_checker(xd))
      {
-       if (ret == XNEE_OK)
-	 {
-	   ;
-	 }
        return XNEE_OK;
      }
 
@@ -123,7 +120,6 @@ xnee_start(xnee_data *xd)
    {
      xnee_delay (xnee_get_interval (xd), "xnee:" );
    }
-   
 
    /*
     * are we recording or are we replaying
@@ -204,6 +200,7 @@ xnee_start(xnee_data *xd)
           XNEE_RETURN_IF_ERR (ret);
 	}
 
+
       /*@ignore@*/
       XTestGrabControl (xnee_get_control_display(xd), True);
       XTestGrabControl (xnee_get_data_display(xd), True);
@@ -257,19 +254,3 @@ xnee_start(xnee_data *xd)
 }
 
 
-
-int 
-xnee_check_true(char *expr)
-{
-   return  (int) ( (strncmp(expr,XNEE_TRUE_STRING,strlen(XNEE_TRUE_STRING))==0)
-                   ||
-                   (strncmp(expr,XNEE_1_STRING,strlen(XNEE_1_STRING))==0) );
-}
-
-int 
-xnee_check_false(char *expr)
-{
-   return  (int)( (strncmp(expr,XNEE_FALSE_STRING,strlen(XNEE_FALSE_STRING))==0)
-                  ||
-                  (strncmp(expr,XNEE_0_STRING,strlen(XNEE_0_STRING))==0) );
-}
